"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLogger = void 0;
const tslib_1 = require("tslib");
const winston_1 = (0, tslib_1.__importDefault)(require("winston"));
const winston_gke_formatter_1 = require("winston-gke-formatter");
const SPLAT = Symbol.for("splat");
// const myPrint = winston.format.printf(
//   ({ level, message, label, timestamp }) => {
//     return `${timestamp} ${level}: ${message}`;
//   }
// );
const concatFormat = winston_1.default.format((info) => {
    // info.severity = info[LEVEL];
    info.message = `${info.message instanceof Object
        ? JSON.stringify(info.message)
        : info.message} ${
    // @ts-ignore
    (info[SPLAT] || []).join(" ")}`;
    return info;
});
const errorStackFormat = winston_1.default.format((info) => {
    if (info instanceof Error) {
        return Object.assign({}, info, {
            stack: info.stack,
            message: info.message,
        });
    }
    return info;
});
const levels = {
    emerg: 0,
    alert: 1,
    crit: 2,
    error: 3,
    warn: 4,
    warning: 4,
    notice: 5,
    info: 6,
    debug: 7,
    silly: 6,
};
const mapGkeLevel = winston_1.default.format((info) => {
    let level = "";
    switch (info.level) {
        case "silly": {
            level = "default";
            break;
        }
        case "debug": {
            level = "debug";
            break;
        }
        case "info": {
            level = "info";
            break;
        }
        case "notice": {
            level = "notice";
            break;
        }
        case "warning": {
            level = "warning";
            break;
        }
        case "warn": {
            level = "warning";
            break;
        }
        case "error": {
            level = "error";
            break;
        }
        case "crit": {
            level = "critical";
            break;
        }
        case "alert": {
            level = "alert";
            break;
        }
        case "emerg": {
            level = "emergency";
            break;
        }
        default: {
            level = "";
        }
    }
    return Object.assign(Object.assign({}, info), { level });
});
const getLogger = () => {
    if (process.env["NODE_ENV"] !== "production") {
        return winston_1.default.createLogger({
            levels,
            format: winston_1.default.format.combine(winston_1.default.format.colorize(), winston_1.default.format.timestamp(), concatFormat(), winston_1.default.format((info) => {
                if (info instanceof Error) {
                    return Object.assign({}, info, {
                        // stack: info.stack,
                        message: info.stack,
                    });
                }
                return info;
            })(), winston_1.default.format.simple()),
            exitOnError: false,
            transports: [
                new winston_1.default.transports.Console({
                    handleExceptions: true,
                }),
            ],
        });
    }
    else {
        return winston_1.default.createLogger({
            levels,
            level: "debug",
            format: winston_1.default.format.combine(mapGkeLevel(), errorStackFormat(), (0, winston_gke_formatter_1.severity)(), winston_1.default.format.json()),
            exitOnError: false,
            transports: [
                new winston_1.default.transports.Console({
                    handleExceptions: true,
                }),
            ],
        });
    }
};
exports.getLogger = getLogger;
